@@ -122,7 +122,9 @@ def _neigh_correction(info, amp_p1p2, idxs_ntop):
         idxs_ntop_old: Original channel indices before correction.
     """
     ntop = len(idxs_ntop)
+    old_verbose = mne.set_log_level('WARNING')  # Suppress output
     adj = mne.channels.find_ch_adjacency(info, 'eeg')[0].toarray()
+    mne.set_log_level(old_verbose)  # Restore level
     np.fill_diagonal(adj, 0)
     # adjacency with only the ntop channels
     sub_adj = adj[idxs_ntop][:, idxs_ntop]
